==> hudi-0.5.0-incubating.src.tgz: hudi-0.5.0-incubating/hudi-common/src/test/java/org/apache/hudi/common/storage/TestStorageSchemes.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.hudi.common.storage;

import static org.junit.Assert.assertFalse;
import static org.junit.Assert.assertTrue;
import static org.junit.Assert.fail;

import org.junit.Test;

public class TestStorageSchemes {

  @Test
  public void testStorageSchemes() {
    assertTrue(StorageSchemes.isSchemeSupported("hdfs"));
    assertFalse(StorageSchemes.isSchemeSupported("s2"));
    assertFalse(StorageSchemes.isAppendSupported("s3a"));
    assertFalse(StorageSchemes.isAppendSupported("gs"));
    assertTrue(StorageSchemes.isAppendSupported("viewfs"));
    try {
      StorageSchemes.isAppendSupported("s2");
      fail("Should throw exception for unsupported schemes");
    } catch (IllegalArgumentException ignore) {
      // expected.
    }
  }
}

==> hudi-0.5.2-incubating.src.tgz: hudi-0.5.2-incubating/hudi-common/src/test/java/org/apache/hudi/common/storage/TestStorageSchemes.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.hudi.common.storage;

import org.junit.Test;

import static org.junit.Assert.assertFalse;
import static org.junit.Assert.assertTrue;
import static org.junit.Assert.fail;

/**
 * Tests {@link StorageSchemes}.
 */
public class TestStorageSchemes {

  @Test
  public void testStorageSchemes() {
    assertTrue(StorageSchemes.isSchemeSupported("hdfs"));
    assertFalse(StorageSchemes.isSchemeSupported("s2"));
    assertFalse(StorageSchemes.isAppendSupported("s3a"));
    assertFalse(StorageSchemes.isAppendSupported("gs"));
    assertFalse(StorageSchemes.isAppendSupported("wasb"));
    assertFalse(StorageSchemes.isAppendSupported("adl"));
    assertFalse(StorageSchemes.isAppendSupported("abfs"));
    assertTrue(StorageSchemes.isAppendSupported("viewfs"));
    try {
      StorageSchemes.isAppendSupported("s2");
      fail("Should throw exception for unsupported schemes");
    } catch (IllegalArgumentException ignore) {
      // expected.
    }
  }
}
